package Bundle::Locale::CLDR::Westerneurope;

use version;

our $VERSION = version->declare('v0.34.1');

=head1 NAME Bundle::Locale::CLDR::Westerneurope

=head1 CONTENTS

Locale::CLDR::Locales::Br 0.34.1
Locale::CLDR::Locales::Ca 0.34.1
Locale::CLDR::Locales::De 0.34.1
Locale::CLDR::Locales::Fr 0.34.1
Locale::CLDR::Locales::Fy 0.34.1
Locale::CLDR::Locales::It 0.34.1
Locale::CLDR::Locales::Lb 0.34.1
Locale::CLDR::Locales::Nl 0.34.1
Locale::CLDR::Locales::Pt 0.34.1
Locale::CLDR::Locales::Rm 0.34.1
Locale::CLDR::Locales::Dsb 0.34.1
Locale::CLDR::Locales::Gsw 0.34.1
Locale::CLDR::Locales::Hsb 0.34.1
Locale::CLDR::Locales::Ksh 0.34.1
Locale::CLDR::Locales::Nds 0.34.1
Locale::CLDR::Locales::Wae 0.34.1
Locale::CLDR::Locales::Br::Any 0.34.1
Locale::CLDR::Locales::Ca::Any 0.34.1
Locale::CLDR::Locales::De::Any 0.34.1
Locale::CLDR::Locales::En::Any 0.34.1
Locale::CLDR::Locales::Fr::Any 0.34.1
Locale::CLDR::Locales::Fy::Any 0.34.1
Locale::CLDR::Locales::It::Any 0.34.1
Locale::CLDR::Locales::Lb::Any 0.34.1
Locale::CLDR::Locales::Nl::Any 0.34.1
Locale::CLDR::Locales::Pt::Any 0.34.1
Locale::CLDR::Locales::Rm::Any 0.34.1
Locale::CLDR::Locales::Dsb::Any 0.34.1
Locale::CLDR::Locales::Gsw::Any 0.34.1
Locale::CLDR::Locales::Hsb::Any 0.34.1
Locale::CLDR::Locales::Ksh::Any 0.34.1
Locale::CLDR::Locales::Nds::Any 0.34.1
Locale::CLDR::Locales::Wae::Any 0.34.1
Locale::CLDR::Locales::Br::Any::Fr 0.34.1
Locale::CLDR::Locales::Ca::Any::Fr 0.34.1
Locale::CLDR::Locales::De::Any::At 0.34.1
Locale::CLDR::Locales::De::Any::Be 0.34.1
Locale::CLDR::Locales::De::Any::Ch 0.34.1
Locale::CLDR::Locales::De::Any::De 0.34.1
Locale::CLDR::Locales::De::Any::Li 0.34.1
Locale::CLDR::Locales::De::Any::Lu 0.34.1
Locale::CLDR::Locales::En::Any::At 0.34.1
Locale::CLDR::Locales::En::Any::Be 0.34.1
Locale::CLDR::Locales::En::Any::Ch 0.34.1
Locale::CLDR::Locales::En::Any::De 0.34.1
Locale::CLDR::Locales::En::Any::Nl 0.34.1
Locale::CLDR::Locales::Fr::Any::Be 0.34.1
Locale::CLDR::Locales::Fr::Any::Ch 0.34.1
Locale::CLDR::Locales::Fr::Any::Fr 0.34.1
Locale::CLDR::Locales::Fr::Any::Lu 0.34.1
Locale::CLDR::Locales::Fr::Any::Mc 0.34.1
Locale::CLDR::Locales::Fy::Any::Nl 0.34.1
Locale::CLDR::Locales::It::Any::Ch 0.34.1
Locale::CLDR::Locales::Lb::Any::Lu 0.34.1
Locale::CLDR::Locales::Nl::Any::Be 0.34.1
Locale::CLDR::Locales::Nl::Any::Nl 0.34.1
Locale::CLDR::Locales::Pt::Any::Ch 0.34.1
Locale::CLDR::Locales::Pt::Any::Lu 0.34.1
Locale::CLDR::Locales::Pt::Any::Pt 0.34.1
Locale::CLDR::Locales::Rm::Any::Ch 0.34.1
Locale::CLDR::Locales::Dsb::Any::De 0.34.1
Locale::CLDR::Locales::En::Any::001 0.34.1
Locale::CLDR::Locales::En::Any::150 0.34.1
Locale::CLDR::Locales::Gsw::Any::Ch 0.34.1
Locale::CLDR::Locales::Gsw::Any::Fr 0.34.1
Locale::CLDR::Locales::Gsw::Any::Li 0.34.1
Locale::CLDR::Locales::Hsb::Any::De 0.34.1
Locale::CLDR::Locales::Ksh::Any::De 0.34.1
Locale::CLDR::Locales::Nds::Any::De 0.34.1
Locale::CLDR::Locales::Nds::Any::Nl 0.34.1
Locale::CLDR::Locales::Wae::Any::Ch 0.34.1

=cut

1;

